==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/fa.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "نمیتوانید داخل دایرکتوری \"config\" تغییراتی ایجاد کنید",
    "See %s" : "مشاهده %s",
    "Sample configuration detected" : "فایل پیکربندی نمونه پیدا شد",
    "PHP %s or higher is required." : "PHP نسخه‌ی %s یا بالاتر نیاز است.",
    "Following databases are supported: %s" : "پایگاه‌داده‌ های ذکر شده مورد نیاز است: %s",
    "The command line tool %s could not be found" : "ابزار کامندلاین %s پیدا نشد",
    "The library %s is not available." : "کتابخانه‌ی %s  در دسترس نیست.",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Invalid image" : "عکس نامعتبر",
    "today" : "امروز",
    "yesterday" : "دیروز",
    "_%n day ago_::_%n days ago_" : ["%n روز پیش","%n روز پیش"],
    "last month" : "ماه قبل",
    "_%n month ago_::_%n months ago_" : ["%n ماه قبل","%n ماه قبل"],
    "last year" : "سال قبل",
    "_%n year ago_::_%n years ago_" : ["%n سال پیش","%n سال پیش"],
    "_%n hour ago_::_%n hours ago_" : ["%n ساعت قبل","%n ساعت قبل"],
    "_%n minute ago_::_%n minutes ago_" : ["%n دقیقه قبل","%n دقیقه قبل"],
    "seconds ago" : "ثانیه‌ها پیش",
    "File name is a reserved word" : "این نام فایل جزو کلمات رزرو می‌باشد",
    "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
    "File name is too long" : "نام فایل خیلی بزرگ است",
    "Empty filename is not allowed" : "نام فایل نمی‌تواند خالی باشد",
    "__language_name__" : "فارسى",
    "Apps" : "  برنامه ها",
    "Users" : "کاربران",
    "Unknown user" : "کاربر نامعلوم",
    "%s enter the database username." : "%s نام کاربری پایگاه داده را وارد نمایید.",
    "%s enter the database name." : "%s نام پایگاه داده را وارد نمایید.",
    "%s you may not use dots in the database name" : "%s شما نباید از نقطه در نام پایگاه داده استفاده نمایید.",
    "Oracle connection could not be established" : "ارتباط اراکل نمیتواند برقرار باشد.",
    "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
    "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
    "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
    "Set an admin password." : "یک رمزعبور برای مدیر تنظیم نمایید.",
    "Could not find category \"%s\"" : "دسته بندی %s یافت نشد",
    "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
    "A valid password must be provided" : "رمز عبور صحیح باید وارد شود",
    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
    "File is currently busy, please try again later" : "فایل در حال حاضر مشغول است، لطفا مجددا تلاش کنید",
    "Can't read file" : "امکان خواندن فایل وجود ندارد",
    "Application is not enabled" : "برنامه فعال نشده است",
    "Authentication error" : "خطا در اعتبار سنجی",
    "Token expired. Please reload page." : "Token منقضی شده است. لطفا دوباره صفحه را بارگذاری نمایید.",
    "Cannot write into \"config\" directory" : "امکان نوشتن درون شاخه‌ی \"config\" وجود ندارد",
    "Please ask your server administrator to install the module." : "لطفا از مدیر سیستم بخواهید تا ماژول را نصب کند.",
    "PHP module %s not installed." : "ماژول PHP %s نصب نشده است.",
    "Please upgrade your database version" : "لطفا نسخه‌ی پایگاه‌داده‌ی خود را بروز کنید",
    "Library %s with a version higher than %s is required - available version %s." : "کتابخانه %s با نسخه‎‌ی بالاتر از %s نیاز است - نسخه‎ی موجود %s.",
    "Library %s with a version lower than %s is required - available version %s." : "کتابخانه %s با نسخه‎‌ی پایین‌تر از %s نیاز است - نسخه‎ی موجود %s.",
    "%s shared »%s« with you" : "%s به اشتراک گذاشته شده است »%s« توسط شما",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "امکان نصب برنامه \"%s\" با توجه به برآورده نکردن نیازمندی زیر وجود ندارد: %s",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 نیاز است"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/fa.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "نمیتوانید داخل دایرکتوری \"config\" تغییراتی ایجاد کنید",
    "See %s" : "مشاهده %s",
    "Sample configuration detected" : "فایل پیکربندی نمونه پیدا شد",
    "PHP %s or higher is required." : "PHP نسخه‌ی %s یا بالاتر نیاز است.",
    "Following databases are supported: %s" : "پایگاه‌داده‌ های ذکر شده مورد نیاز است: %s",
    "The command line tool %s could not be found" : "ابزار کامندلاین %s پیدا نشد",
    "The library %s is not available." : "کتابخانه‌ی %s  در دسترس نیست.",
    "Authentication" : "احراز هویت",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Invalid image" : "عکس نامعتبر",
    "today" : "امروز",
    "yesterday" : "دیروز",
    "_%n day ago_::_%n days ago_" : ["%n روز پیش","%n روز پیش"],
    "last month" : "ماه قبل",
    "_%n month ago_::_%n months ago_" : ["%n ماه قبل","%n ماه قبل"],
    "last year" : "سال قبل",
    "_%n year ago_::_%n years ago_" : ["%n سال پیش","%n سال پیش"],
    "_%n hour ago_::_%n hours ago_" : ["%n ساعت قبل","%n ساعت قبل"],
    "_%n minute ago_::_%n minutes ago_" : ["%n دقیقه قبل","%n دقیقه قبل"],
    "seconds ago" : "ثانیه‌ها پیش",
    "File name is a reserved word" : "این نام فایل جزو کلمات رزرو می‌باشد",
    "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
    "File name is too long" : "نام فایل خیلی بزرگ است",
    "Empty filename is not allowed" : "نام فایل نمی‌تواند خالی باشد",
    "__language_name__" : "فارسى",
    "Help" : "کمک",
    "Apps" : "  برنامه ها",
    "Settings" : "تنظیمات",
    "Log out" : "خروج",
    "Users" : "کاربران",
    "Unknown user" : "کاربر نامعلوم",
    "Sharing" : "اشتراک گذاری",
    "Security" : "امنیت",
    "Personal info" : "مشخصات شخصی",
    "%s enter the database username." : "%s نام کاربری پایگاه داده را وارد نمایید.",
    "%s enter the database name." : "%s نام پایگاه داده را وارد نمایید.",
    "%s you may not use dots in the database name" : "%s شما نباید از نقطه در نام پایگاه داده استفاده نمایید.",
    "Oracle connection could not be established" : "ارتباط اراکل نمیتواند برقرار باشد.",
    "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
    "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
    "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
    "Set an admin password." : "یک رمزعبور برای مدیر تنظیم نمایید.",
    "Could not find category \"%s\"" : "دسته بندی %s یافت نشد",
    "Sunday" : "یکشنبه",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنجشنبه",
    "Friday" : "جمعه",
    "Saturday" : "شنبه",
    "Sun." : "یکشنبه",
    "Mon." : "دوشنبه",
    "Tue." : "سه شنبه",
    "Wed." : "چهارشنبه",
    "Thu." : "پنج شنبه",
    "Fri." : "جمعه",
    "Sat." : "شنبه",
    "Su" : "یک‌شنبه",
    "Mo" : "دوشنبه",
    "Tu" : "سه‌شنبه",
    "We" : "چهار‌شنبه",
    "Th" : "پنج‌شنبه",
    "Fr" : "جمعه",
    "Sa" : "شنبه",
    "January" : "ژانویه",
    "February" : "فبریه",
    "March" : "مارس",
    "April" : "آوریل",
    "May" : "می",
    "June" : "ژوئن",
    "July" : "جولای",
    "August" : "آگوست",
    "September" : "سپتامبر",
    "October" : "اکتبر",
    "November" : "نوامبر",
    "December" : "دسامبر",
    "Jan." : "ژانویه",
    "Feb." : "فوریه",
    "Mar." : "مارچ",
    "Apr." : "آوریل",
    "May." : "می",
    "Jun." : "ژوئن",
    "Jul." : "جولای",
    "Aug." : "آگوست",
    "Sep." : "سپتامبر",
    "Oct." : "اکتبر",
    "Nov." : "نوامبر",
    "Dec." : "دسامبر",
    "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
    "A valid password must be provided" : "رمز عبور صحیح باید وارد شود",
    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
    "User disabled" : "کاربر غیرفعال",
    "File is currently busy, please try again later" : "فایل در حال حاضر مشغول است، لطفا مجددا تلاش کنید",
    "Can't read file" : "امکان خواندن فایل وجود ندارد",
    "Application is not enabled" : "برنامه فعال نشده است",
    "Authentication error" : "خطا در اعتبار سنجی",
    "Token expired. Please reload page." : "Token منقضی شده است. لطفا دوباره صفحه را بارگذاری نمایید.",
    "Cannot write into \"config\" directory" : "امکان نوشتن درون شاخه‌ی \"config\" وجود ندارد",
    "Please ask your server administrator to install the module." : "لطفا از مدیر سیستم بخواهید تا ماژول را نصب کند.",
    "PHP module %s not installed." : "ماژول PHP %s نصب نشده است.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 نیاز است",
    "Please upgrade your database version" : "لطفا نسخه‌ی پایگاه‌داده‌ی خود را بروز کنید",
    "Create" : "ایجاد کردن",
    "Change" : "تغییر",
    "Delete" : "حذف",
    "Share" : "هم‌رسانی",
    "Unlimited" : "نامحدود",
    "Verifying" : "تایید شدن",
    "Verifying …" : "در حال تایید شدن...",
    "Verify" : "تأیید کنید"
},
"nplurals=2; plural=(n > 1);");
